#!/bin/bash

#Dependencies
#yad for tray-icon
#zenity for basic dialogs
#!/bin/bash
gfx="$HOME/.wm_optical/app.builder/gfx"

ask(){

	case $1 in
	
		--output-label)
			path="$(zenity --file-selection --title="Build image" --save --filename="$label" --confirm-overwrite 2> /dev/null)"
				if [ "$?" -eq 1 ]
					then
				exit
				fi
		;;
		
		--output)
		path="$(zenity --file-selection --save --title="Build image" --filename="" --confirm-overwrite 2> /dev/null)"
				if [ "$?" -eq 1 ]
					then
				exit
				fi
		;;
esac

#Output path association
output_bin="$path.bin"
output_toc="$path.toc"
output_cue="$path.cue"
}

get_from(){
TMP="$(mktemp -q /tmp/wm_optical.ib_XXXXXXXXX)"
udisks --show-info "$1" > "$TMP"

for arg    # "in $@" is implied
    do
        case $arg in
        
        --media)
			media="$(cat "$TMP" | grep "media" | sed 1d | sed 1d | awk '{print $2}')"
		;;
        
        --block_size)
			block_size="$(cat "$TMP" | grep "block size:" | awk '{print $3}')"
		;;
        
        --label)
			label_a=$(cat "$TMP" | grep "label:" | sed 's/label:                       //g')
			label="$(echo "$label_a" | sed 's/  //g')"
		;;
		
        --size_input)
			size_input="$(cat "$TMP" | grep "size" | sed 2d | awk '{print $2}')"
		;;
        
        esac
done
}

prepare(){
udisks --unmount "$1" 2> /dev/null
PIPE=$(mktemp -u --tmpdir ${0##*/}.XXXXXXXX)
mkfifo $PIPE
exec 3<> $PIPE
}

ui(){
		
		get_monitor_info(){
			size_out="$(du -B 1 "$output_bin" | awk '{print $1}' 2> /dev/null)"
			progress_z="$(echo "($size_out*100/$size_input)" | bc)"
			progress_r="$(echo "scale=1;($size_out*100/$size_input)" | bc -l)"
			size="$(du -h "$output_bin" | awk '{print $1}' 2> /dev/null)"
			echo "$size_out $progress_z $progress_r $size"
			#yad values
			icon="$gfx/$progress_z.svg"
			title="<b>▶ Building image...                    </b>"
			progress="<b>$progress_r%</b> | $size"
			text="<b>From:</b> $label \n<b>Path:</b> $output_bin"
		}
		
		print_yad(){
		case $1 in
			--dd)
			
			case $2 in
			
			--monitor)
				#print
				echo "icon:$icon" >&3
				echo "tooltip:$title $progress \n\n$text" >&3
				echo "menu:Abort!kill -s TERM $PID_dd" >&3
			;;
			
			esac
			;;
			
			--cdrdao)
			case $2 in
			
			--monitor)
				progress="$size"
				#print
				echo "icon:$icon" >&3
				echo "tooltip:$title $progress \n\n$text" >&3
				echo "menu:Abort!kill -s TERM $PID_cdrdao" >&3
			;;
			
			esac
			;;
		esac
		}
		
		monitor(){
			while :;do
			if [ -a "$output_bin" ];
				then
					get_monitor_info 
					print_yad $1 --monitor
					sleep 1
			fi
		done
		}
					
		case $1 in
			--dd-tray-osd)
				notify-send "Building image..." "Receiving data from source:\n▸ $device"
				yad --notification --image="$gfx/0.svg" --text="<b>▶ Waiting for device...                    </b>" --listen <&3 2> /dev/null & PID_yad=$! 
				monitor --dd & PID_monitor=$!
				
				wait $PID_dd
				exit_code="$?"
				
				kill -s TERM $PID_monitor
				kill -s TERM $PID_yad
	
				case $exit_code in
					0)
						notify-send "Finished" "Image saved sacessfully on:\n▸ $output_bin" -t 2
					;;
					
					143)
						notify-send "Failed" "Process aborted by user signal" -t 5
					;;
					
					*)
						notify-send "Failed" "Process stoped with exit code $exit_code" -t 5
					;;
				
				esac
			;;
				
			--cdrdao-tray-osd)
				notify-send "Building image..." "Receiving data from source:\n▸ $device"
				
				yad --notification --image="$gfx/0.svg" --text="<b>▶ Waiting for device...                    </b>" --listen <&3 2> /dev/null & PID_yad=$! 
				monitor --cdrdao & PID_monitor=$!
				
				wait $PID_cdrdao
				exit_code="$?"
				
				kill -s TERM $PID_monitor
				kill -s TERM $PID_yad
	
				case $exit_code in
					0)
						notify-send "Finished" "Image saved sacessfully on:\n▸ $output_bin" -t 2
					;;
					
					143)
						notify-send "Failed" "Process aborted by user signal" -t 5
					;;
					
					*)
						notify-send "Failed" "Process stoped with exit code $exit_code" -t 5
					;;
				
				esac
			;;
esac			
}
		
